@@ -6,6 +6,9 @@ import codeop
 import inspect
 import io
 import json
+import os
+import posixpath
+import shutil
 import sys
 import traceback
 from contextlib import contextmanager, redirect_stdout, redirect_stderr
@@ -46,6 +49,7 @@ parser.add_argument('--local-ns-file', nargs='?')
 parser.add_argument('--postload-input-serializers', nargs='?')
 parser.add_argument('--predump-output-serializers', nargs='?')
 parser.add_argument('--output-name', action='append')
+parser.add_argument('--workdir', nargs='?')
 
 
 def _deserialize(path, default=None):
@@ -167,6 +171,10 @@ async def run_code(args):
         output[CELL_OUTPUT] = command_output.getvalue().strip(),
         if args.output_name:
             output[CELL_LOCAL_NS] = _serialize(compiler, user_ns, args)
+            if args.workdir:
+                dest_path = os.path.join(args.workdir, os.path.basename(output[CELL_LOCAL_NS]))
+                shutil.move(output[CELL_LOCAL_NS], dest_path)
+                output[CELL_LOCAL_NS] = dest_path
     except BaseException:
         # Populate output object
         output[CELL_OUTPUT] = traceback.format_exc()
